GenuiXRateLimitError class

Thrown when the API returns a rate limit response (429).

Check retryAfter to know how many seconds to wait before retrying.

Implemented types

Constructors

GenuiXRateLimitError({int? retryAfter, required String body})
Creates a GenuiXRateLimitError.
const

Properties

body String
The response body.
final
hashCode int
The hash code for this object.
no setterinherited
retryAfter int?
Seconds to wait before retrying, parsed from the Retry-After header.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited